( function( window, document, $, undefined ) {
	'use strict';

	var fmq = {

		filters : [],

		/**
		 * Initialize fmq behavior.
		 *
		 * @since 1.0.0
		 */
		init : function () {
			fmq.changedFilters();
			fmq.bind();
		},

		/**
		 * Bind all event methods.
		 *
		 * @since 1.0.0
		 */
		bind : function () {
			jQuery( function( $ ) {
				$( '.fmq-filter' )
					.select2({
						width: '100%',
						allowClear : true,
						multiple : true
					})
					.on( 'change', fmq.changedFilters );
			});
		},

		/**
		 * Binding for filter change events.
		 *
		 * @since 1.0.0
		 */
		changedFilters : function() {
			fmq.updateFilters();
			fmq.updateLinkHref('.fmq-apply-filters');
			fmq.updateLinkHref('.fmq-rss');
		},

		/**
		 * Update current filters.
		 *
		 * @since 1.0.0
		 */
		updateFilters : function () {
			fmq.filters.topic = fmq.getActiveFilters( 'topic' );
			fmq.filters.technology = fmq.getActiveFilters( 'technology' );
		},

		/**
		 * Get currently active filters
		 *
		 * @since 1.0.0
		 */
		getActiveFilters : function ( taxonomy ) {
			return $( '.fmq-filter-' + taxonomy ).val();
		},

		/**
		 * Update a link href with current filters.
		 *
		 * @since 1.0.0
		 */
		updateLinkHref: function ( link ) {

			// Setup filter string
			var $link = $(link);
			var filterString = '/?filter=true';

			// Convert filters to URL string
			for ( var taxonomy in fmq.filters ) {
				if ( 'undefined' !== typeof fmq.filters[taxonomy] && null !== fmq.filters[taxonomy] ) {
					filterString += '&filter-' + taxonomy + '=' + fmq.filters[taxonomy].toString();
				}
			}

			// Clear filter string if no filters are applied
			if ( '/?filter=true' === filterString ) {
				filterString = '';
			}

			// Update link href
			$link.attr( 'href', $link.data('base-url') + filterString );
		}
	};

	fmq.init();

})( window, document, jQuery );
